[prev in list] [next in list] [prev in thread] [next in thread] 

List:       graphicsmagick-commit
Subject:    [GM-commit] GraphicsMagick: Documentation improvements, and remove MagickExp...
From:       GraphicsMagick Commits <graphicsmagick-commit () lists ! sourceforge ! net>
Date:       2020-03-07 22:06:14
Message-ID: mailman.35814.1583618787.1535.graphicsmagick-commit () lists ! sourceforge ! net
[Download RAW message or body]

changeset 05b03e2ca54c in /hg/GraphicsMagick
details: http://hg.GraphicsMagick.org/hg/GraphicsMagick?cmd=changeset;node=05b03e2ca54c
                
summary: Documentation improvements, and remove MagickExport for DestroyLogInfo()

diffstat:

 ChangeLog                              |   7 +++++
 Makefile.in                            |   2 +
 VisualMagick/installer/inc/version.isx |   4 +-
 magick/color.c                         |   2 +-
 magick/log-private.h                   |   2 +-
 magick/log.c                           |  45 +++++++++++++++++++--------------
 magick/log.h                           |   2 +-
 magick/render.c                        |   2 +-
 magick/resize.c                        |  14 +++++++---
 magick/statistics.c                    |   2 +-
 magick/version.h                       |   4 +-
 scripts/whatis.txt                     |  27 ++++++++++---------
 www/Changelog.html                     |   8 ++++++
 www/api/Makefile.am                    |   2 +
 www/api/api.html                       |   2 +
 www/api/api.rst                        |   4 +++
 www/api/color.html                     |   2 +-
 www/api/render.html                    |   2 +-
 www/api/resize.html                    |  14 +++++++---
 www/api/statistics.html                |   8 +++---
 20 files changed, 100 insertions(+), 55 deletions(-)

diffs (truncated from 546 to 500 lines):

diff -r a41ed6b083b3 -r 05b03e2ca54c ChangeLog
--- a/ChangeLog	Wed Mar 04 08:35:30 2020 -0600
+++ b/ChangeLog	Sat Mar 07 16:03:03 2020 -0600
@@ -1,3 +1,10 @@
+2020-03-07  Bob Friesenhahn  <bfriesen@simple.dallas.tx.us>
+
+	* www/api/api.rst: Add functions from log.c and render.c.
+
+	* magick/log.c (DestroyLogInfo): DestroyLogInfo is no longer
+	marked MagickExport.
+
 2020-03-04  Bob Friesenhahn  <bfriesen@simple.dallas.tx.us>
 
 	* magick/api.h: Add "magick/enum_strings.h" to API headers.
diff -r a41ed6b083b3 -r 05b03e2ca54c Makefile.in
--- a/Makefile.in	Wed Mar 04 08:35:30 2020 -0600
+++ b/Makefile.in	Sat Mar 07 16:03:03 2020 -0600
@@ -4599,6 +4599,7 @@
 	$(WWWAPIDIR)/image.html \
 	$(WWWAPIDIR)/import.html \
 	$(WWWAPIDIR)/list.html \
+	$(WWWAPIDIR)/log.html \
 	$(WWWAPIDIR)/magick.html \
 	$(WWWAPIDIR)/memory.html \
 	$(WWWAPIDIR)/monitor.html \
@@ -4652,6 +4653,7 @@
 	www/api/image.html \
 	www/api/import.html \
 	www/api/list.html \
+	www/api/log.html \
 	www/api/magick.html \
 	www/api/memory.html \
 	www/api/monitor.html \
diff -r a41ed6b083b3 -r 05b03e2ca54c VisualMagick/installer/inc/version.isx
--- a/VisualMagick/installer/inc/version.isx	Wed Mar 04 08:35:30 2020 -0600
+++ b/VisualMagick/installer/inc/version.isx	Sat Mar 07 16:03:03 2020 -0600
@@ -10,5 +10,5 @@
 
 #define public MagickPackageName "GraphicsMagick"
 #define public MagickPackageVersion "1.4"
-#define public MagickPackageVersionAddendum ".020200304"
-#define public MagickPackageReleaseDate "snapshot-20200304"
+#define public MagickPackageVersionAddendum ".020200307"
+#define public MagickPackageReleaseDate "snapshot-20200307"
diff -r a41ed6b083b3 -r 05b03e2ca54c magick/color.c
--- a/magick/color.c	Wed Mar 04 08:35:30 2020 -0600
+++ b/magick/color.c	Sat Mar 07 16:03:03 2020 -0600
@@ -410,7 +410,7 @@
 %  which specify the number of times each unique color occurs in the image.
 %  The referenced colors parameter is updated with the number of unique colors
 %  in the image. The returned array should be deallocated by the user once it
-%  is no longer ndded.
+%  is no longer needed.
 %
 %  The format of the GetColorHistogram method is:
 %
diff -r a41ed6b083b3 -r 05b03e2ca54c magick/log-private.h
--- a/magick/log-private.h	Wed Mar 04 08:35:30 2020 -0600
+++ b/magick/log-private.h	Sat Mar 07 16:03:03 2020 -0600
@@ -9,7 +9,7 @@
   Log methods.
 */
 
-extern MagickExport void
+extern void
   DestroyLogInfo(void);
 
 extern MagickPassFail
diff -r a41ed6b083b3 -r 05b03e2ca54c magick/log.h
--- a/magick/log.h	Wed Mar 04 08:35:30 2020 -0600
+++ b/magick/log.h	Sat Mar 07 16:03:03 2020 -0600
@@ -72,7 +72,7 @@
 } LogEventType;
 
 typedef void
-  (*LogMethod)(const ExceptionType,const char *);
+  (*LogMethod)(const ExceptionType type,const char *text);
 
 /*
   Method declarations.
diff -r a41ed6b083b3 -r 05b03e2ca54c magick/render.c
--- a/magick/render.c	Wed Mar 04 08:35:30 2020 -0600
+++ b/magick/render.c	Sat Mar 07 16:03:03 2020 -0600
@@ -990,7 +990,7 @@
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  DestroyDrawInfo() deallocates memory associated with an DrawInfo
-%  structure.
+%  structure.  Nothing is done if the pointer passed is NULL.
 %
 %  The format of the DestroyDrawInfo method is:
 %
diff -r a41ed6b083b3 -r 05b03e2ca54c magick/resize.c
--- a/magick/resize.c	Wed Mar 04 08:35:30 2020 -0600
+++ b/magick/resize.c	Sat Mar 07 16:03:03 2020 -0600
@@ -1498,7 +1498,8 @@
 %
 %  SampleImage() scales an image to the desired dimensions with pixel
 %  sampling.  Unlike other scaling methods, this method does not introduce
-%  any additional color into the scaled image.
+%  any additional color into the scaled image. SampleImage() is extremely
+%  fast and may be used where speed is most important.
 %
 %  The format of the SampleImage method is:
 %
@@ -1663,7 +1664,10 @@
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  ScaleImage() changes the size of an image to the given dimensions.
+%  ScaleImage() changes the size of an image to the specified dimensions.
+%  This method is reasonably fast but it is not currently multi-threaded
+%  and does not support image filters. The quality of the resized image
+%  is sufficient for most purposes.
 %
 %  The format of the ScaleImage method is:
 %
@@ -2103,8 +2107,10 @@
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  ThumbnailImage() changes the size of an image to the given dimensions.
-%  This method was designed by Bob Friesenhahn as a low cost thumbnail
-%  generator.
+%  This method was designed as a low cost thumbnail generator.
+%  ThumbnailImage() is typically very fast but an attempt is made to improve
+%  quality by first using a simple sampling algorithm for part of the
+%  reduction, and then a filtering algorithm to produce the final image.
 %
 %  The format of the ThumbnailImage method is:
 %
diff -r a41ed6b083b3 -r 05b03e2ca54c magick/statistics.c
--- a/magick/statistics.c	Wed Mar 04 08:35:30 2020 -0600
+++ b/magick/statistics.c	Sat Mar 07 16:03:03 2020 -0600
@@ -40,7 +40,7 @@
 %  The format of the GetImageStatistics method is:
 %
 %      MagickPassFail GetImageStatistics(const Image *image,
-%                                        ImageStatistics *statistics
+%                                        ImageStatistics *statistics,
 %                                        ExceptionInfo *exception)
 %
 %  A description of each parameter follows:
diff -r a41ed6b083b3 -r 05b03e2ca54c magick/version.h
--- a/magick/version.h	Wed Mar 04 08:35:30 2020 -0600
+++ b/magick/version.h	Sat Mar 07 16:03:03 2020 -0600
@@ -38,8 +38,8 @@
 #define MagickLibVersion  0x242100
 #define MagickLibVersionText  "1.4"
 #define MagickLibVersionNumber 24,21,0
-#define MagickChangeDate   "20200304"
-#define MagickReleaseDate  "snapshot-20200304"
+#define MagickChangeDate   "20200307"
+#define MagickReleaseDate  "snapshot-20200307"
 
 /*
   The MagickLibInterfaceNewest and MagickLibInterfaceOldest defines
diff -r a41ed6b083b3 -r 05b03e2ca54c scripts/whatis.txt
--- a/scripts/whatis.txt	Wed Mar 04 08:35:30 2020 -0600
+++ b/scripts/whatis.txt	Sat Mar 07 16:03:03 2020 -0600
@@ -4,31 +4,32 @@
 animate.c          Interactively animate an image sequence
 annotate.c         Annotate an image with text
 attribute.c        Access key,value image attributes
-average.c	   Image averaging functions
+average.c          Image averaging functions
 blob.c             Read or write formatted images in memory (BLOBs)
-cdl.c		   Apply ASC CDL transform to image
+cdl.c              Apply ASC CDL transform to image
 channel.c          Image channel functions
 color.c            Color related functions
-colormap.c	   Colormap related functions
+colormap.c         Colormap related functions
 constitute.c       Read or write an image
 compare.c          Compare images
 composite.c        Merge image pixels using a specified algorithm
 confirm_access.c   Access confirmation functions
 decorate.c         Add decorative frames and borders
 deprecate.c        Methods which should no longer be used
-describe.c	   Methods to describe an image
+describe.c         Methods to describe an image
 display.c          Interactively display and edit an image
-export.c	   Export image pixels into common representations
+export.c           Export image pixels into common representations
 render.c           Low-level methods to draw on an image
 draw.c             User-friendly methods to draw on an image
 effect.c           Image effects methods
 fx.c               Image special effects methods
 enhance.c          Methods to enhance or adjust an image
 error.c            Error reporting methods
-hclut.c		   Apply Hald CLUT to image
+hclut.c            Apply Hald CLUT to image
 image.c            Miscellaneous image methods
-import.c	   Import image pixels from common representations
+import.c           Import image pixels from common representations
 list.c             Image list support
+log.c              Event logging support
 magick.c           Image format support interfaces
 memory.c           Memory allocation/deallocation functions
 monitor.c          Progress monitor support
@@ -37,7 +38,7 @@
 paint.c            Methods to fill image pixel regions
 pixel_cache.c      Image pixel cache (working pixels).
 pixel_iterator.c   Pixel iterator pattern support functions
-plasma.c	   Create a Plasma fractal image.
+plasma.c           Create a Plasma fractal image.
 profile.c          Manipulate embedded profiles
 quantize.c         Reduce the number of colors in an image
 registry.c         In-memory image registration interface
@@ -45,11 +46,11 @@
 segment.c          Segment and image with thresholding using the fuzzy c-means \
method  shear.c            Rotate image, shear image, or apply a 2D affine \
transformation  signature.c        Add a digital signature to the image
-statistics.c	   Compute image statistics
-texture.c	   Image texture functions
+statistics.c       Compute image statistics
+texture.c          Image texture functions
 transform.c        Crop, flip, flop, roll, coalesce, etc.
 resize.c           Resize an image
 widget.c           X11 Widgets
-drawing_wand.c	   Wand vector drawing interfaces
-magick_wand.c	   Wand image processing interfaces
-pixel_wand.c	   Wand pixel access interfaces
+drawing_wand.c     Wand vector drawing interfaces
+magick_wand.c      Wand image processing interfaces
+pixel_wand.c       Wand pixel access interfaces
diff -r a41ed6b083b3 -r 05b03e2ca54c www/Changelog.html
--- a/www/Changelog.html	Wed Mar 04 08:35:30 2020 -0600
+++ b/www/Changelog.html	Sat Mar 07 16:03:03 2020 -0600
@@ -35,6 +35,14 @@
 <div class="document">
 
 
+<p>2020-03-07  Bob Friesenhahn  &lt;<a class="reference external" \
href="mailto:bfriesen&#37;&#52;&#48;simple&#46;dallas&#46;tx&#46;us">bfriesen<span>&#6 \
4;</span>simple<span>&#46;</span>dallas<span>&#46;</span>tx<span>&#46;</span>us</a>&gt;</p>
 +<blockquote>
+<ul class="simple">
+<li>www/api/api.rst: Add functions from log.c and render.c.</li>
+<li>magick/log.c (DestroyLogInfo): DestroyLogInfo is no longer
+marked MagickExport.</li>
+</ul>
+</blockquote>
 <p>2020-03-04  Bob Friesenhahn  &lt;<a class="reference external" \
href="mailto:bfriesen&#37;&#52;&#48;simple&#46;dallas&#46;tx&#46;us">bfriesen<span>&#6 \
4;</span>simple<span>&#46;</span>dallas<span>&#46;</span>tx<span>&#46;</span>us</a>&gt;</p>
  <blockquote>
 <ul class="simple">
diff -r a41ed6b083b3 -r 05b03e2ca54c www/api/Makefile.am
--- a/www/api/Makefile.am	Wed Mar 04 08:35:30 2020 -0600
+++ b/www/api/Makefile.am	Sat Mar 07 16:03:03 2020 -0600
@@ -39,6 +39,7 @@
 	$(WWWAPIDIR)/image.html \
 	$(WWWAPIDIR)/import.html \
 	$(WWWAPIDIR)/list.html \
+	$(WWWAPIDIR)/log.html \
 	$(WWWAPIDIR)/magick.html \
 	$(WWWAPIDIR)/memory.html \
 	$(WWWAPIDIR)/monitor.html \
@@ -92,6 +93,7 @@
 	www/api/image.html \
 	www/api/import.html \
 	www/api/list.html \
+	www/api/log.html \
 	www/api/magick.html \
 	www/api/memory.html \
 	www/api/monitor.html \
diff -r a41ed6b083b3 -r 05b03e2ca54c www/api/api.html
--- a/www/api/api.html	Wed Mar 04 08:35:30 2020 -0600
+++ b/www/api/api.html	Sat Mar 07 16:03:03 2020 -0600
@@ -77,6 +77,7 @@
 <li><a class="reference external" href="image.html">Image</a>: Miscellaneous image \
methods</li>  <li><a class="reference external" href="import.html">Import</a> : \
Import image pixels from common representations</li>  <li><a class="reference \
external" href="list.html">List</a>: Manage image lists</li> +<li><a class="reference \
external" href="log.html">Log</a>: Event logging support</li>  <li><a \
class="reference external" href="magick.html">Magick</a>: Image format support \
interfaces</li>  <li><a class="reference external" href="memory.html">Memory</a>: \
Memory allocation methods</li>  <li><a class="reference external" \
href="monitor.html">Monitor</a>: Progress monitor callbacks</li> @@ -89,6 +90,7 @@
 <li><a class="reference external" href="profile.html">Profile</a>: Attached profile \
access</li>  <li><a class="reference external" href="quantize.html">Quantize</a>: \
Reduce image colors or assign image colors from colormap</li>  <li><a \
class="reference external" href="registry.html">Registry</a>: Store and retrieve \
images in memory by ID</li> +<li><a class="reference external" \
href="render.html">Render</a>: Render vector graphics</li>  <li><a class="reference \
external" href="resize.html">Resize</a>: Resize an Image</li>  <li><a \
class="reference external" href="resource.html">Resource</a>: Set and get resource \
limits</li>  <li><a class="reference external" href="segment.html">Segment</a>: \
                Coalese similar image colors</li>
diff -r a41ed6b083b3 -r 05b03e2ca54c www/api/api.rst
--- a/www/api/api.rst	Wed Mar 04 08:35:30 2020 -0600
+++ b/www/api/api.rst	Sat Mar 07 16:03:03 2020 -0600
@@ -32,6 +32,7 @@
 .. _Image : image.html
 .. _Import : import.html
 .. _List : list.html
+.. _Log : log.html
 .. _Magick : magick.html
 .. _Memory : memory.html
 .. _Monitor : monitor.html
@@ -44,6 +45,7 @@
 .. _Profile : profile.html
 .. _Quantize : quantize.html
 .. _Registry : registry.html
+.. _Render : render.html
 .. _Resize : resize.html
 .. _Resource : resource.html
 .. _Segment : segment.html
@@ -93,6 +95,7 @@
   * Image_: Miscellaneous image methods
   * Import_ : Import image pixels from common representations
   * List_: Manage image lists
+  * Log_: Event logging support
   * Magick_: Image format support interfaces
   * Memory_: Memory allocation methods
   * Monitor_: Progress monitor callbacks
@@ -105,6 +108,7 @@
   * Profile_: Attached profile access
   * Quantize_: Reduce image colors or assign image colors from colormap
   * Registry_: Store and retrieve images in memory by ID
+  * Render_: Render vector graphics
   * Resize_: Resize an Image
   * Resource_: Set and get resource limits
   * Segment_: Coalese similar image colors
diff -r a41ed6b083b3 -r 05b03e2ca54c www/api/color.html
--- a/www/api/color.html	Wed Mar 04 08:35:30 2020 -0600
+++ b/www/api/color.html	Sat Mar 07 16:03:03 2020 -0600
@@ -59,7 +59,7 @@
 which specify the number of times each unique color occurs in the image.
 The referenced colors parameter is updated with the number of unique colors
 in the image. The returned array should be deallocated by the user once it
-is no longer ndded.</p>
+is no longer needed.</p>
 <p>The format of the GetColorHistogram method is:</p>
 <pre class="literal-block">
 HistogramColorPacket *GetColorHistogram( const <a class="reference external" \
                href="../api/types.html#image">Image</a> *, unsigned long *colors,
diff -r a41ed6b083b3 -r 05b03e2ca54c www/api/render.html
--- a/www/api/render.html	Wed Mar 04 08:35:30 2020 -0600
+++ b/www/api/render.html	Sat Mar 07 16:03:03 2020 -0600
@@ -84,7 +84,7 @@
 <div class="section" id="id2">
 <h2>Description</h2>
 <p>DestroyDrawInfo() deallocates memory associated with an DrawInfo
-structure.</p>
+structure.  Nothing is done if the pointer passed is NULL.</p>
 <p>The format of the DestroyDrawInfo method is:</p>
 <pre class="literal-block">
 void DestroyDrawInfo( <a class="reference external" \
                href="../api/types.html#drawinfo">DrawInfo</a> *draw_info );
diff -r a41ed6b083b3 -r 05b03e2ca54c www/api/resize.html
--- a/www/api/resize.html	Wed Mar 04 08:35:30 2020 -0600
+++ b/www/api/resize.html	Sat Mar 07 16:03:03 2020 -0600
@@ -155,7 +155,8 @@
 <h2>Description</h2>
 <p>SampleImage() scales an image to the desired dimensions with pixel
 sampling.  Unlike other scaling methods, this method does not introduce
-any additional color into the scaled image.</p>
+any additional color into the scaled image. SampleImage() is extremely
+fast and may be used where speed is most important.</p>
 <p>The format of the SampleImage method is:</p>
 <pre class="literal-block">
 <a class="reference external" href="../api/types.html#image">Image</a> *SampleImage( \
const <a class="reference external" href="../api/types.html#image">Image</a> *image, \
const unsigned long columns, @@ -184,7 +185,10 @@
 </div>
 <div class="section" id="id8">
 <h2>Description</h2>


_______________________________________________
Graphicsmagick-commit mailing list
Graphicsmagick-commit@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/graphicsmagick-commit


[prev in list] [next in list] [prev in thread] [next in thread] 

Configure | About | News | Add a list | Sponsored by KoreLogic
diff -r a41ed6b083b3 -r 05b03e2ca54c magick/log.c
--- a/magick/log.c	Wed Mar 04 08:35:30 2020 -0600
+++ b/magick/log.c	Sat Mar 07 16:03:03 2020 -0600
@@ -238,7 +238,7 @@
 %
 %
 */
-MagickExport void DestroyLogInfo(void)
+void DestroyLogInfo(void)
 {
   if (log_info->file != (FILE *) NULL)
     if ((log_info->file != stdout) && (log_info->file != stderr))
@@ -445,11 +445,11 @@
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  LogMagickEvent() logs an event as determined by the log configuration file.
-%  If an error occurs, False is returned otherwise True.
+%  If an error occurs, MagickFail is returned otherwise MagickPass.
 %
 %  The format of the LogMagickEvent method is:
 %
 %      unsigned int LogMagickEvent(const LogEventType type,const char *module,
 %        const char *function,const unsigned long line,const char *format,...)
 %
 %  A description of each parameter follows:
@@ -466,7 +466,7 @@
 %
 %
 */
-MagickExport  unsigned int LogMagickEventList(const ExceptionType type,
+MagickExport MagickPassFail LogMagickEventList(const ExceptionType type,
   const char *module,const char *function,const unsigned long line,
   const char *format,va_list operands)
 {
@@ -546,7 +546,7 @@
             }
         }
       if (!enabled)
-        return(True);
+        return(MagickPass);
     }
 
   /* fixup module info to just include the filename - and not the
@@ -678,7 +678,7 @@
       (void) fprintf(log_info->file,"</record>\n");
       (void) fflush(log_info->file);
       UnlockSemaphoreInfo(log_info->log_semaphore);
-      return(True);
+      return(MagickPass);
     }
   if (((unsigned int) log_info->output_type) & TXTFileOutput)
     {
@@ -718,7 +718,7 @@
                        severity, event);
       (void) fflush(log_info->file);
       UnlockSemaphoreInfo(log_info->log_semaphore);
-      return(True);
+      return(MagickPass);
     }
 #if defined(MSWINDOWS)
   if (log_info->output_type & Win32DebugOutput)
@@ -887,9 +887,9 @@
       log_info->method(type,buffer);
     }
   UnlockSemaphoreInfo(log_info->log_semaphore);
-  return(True);
+  return(MagickPass);
 }
-MagickExport unsigned int LogMagickEvent(const ExceptionType type,
+MagickExport MagickPassFail LogMagickEvent(const ExceptionType type,
   const char *module,const char *function,const unsigned long line,
   const char *format,...)
 {
@@ -921,7 +921,7 @@
 %
 %  The format of the ReadLogConfigureFile method is:
 %
-%      unsigned int ReadLogConfigureFile(const char *basename,
+%      MagickPassFail ReadLogConfigureFile(const char *basename,
 %        const unsigned int depth,ExceptionInfo *exception)
 %
 %  A description of each parameter follows:
@@ -1190,14 +1190,13 @@
 %                                                                             %
 %                                                                             %
 %                                                                             %
-%                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  SetLogFormat() sets the format for the "human readable" log record.
 %
 %  The format of the LogMagickFormat method is:
 %
-%      SetLogFormat(const char *format)
+%      void SetLogFormat(const char *format)
 %
 %  A description of each parameter follows:
 %
@@ -1223,19 +1222,18 @@
 %                                                                             %
 %                                                                             %
 %                                                                             %
-%                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  SetLogMethod() sets the method that should be called when logging.
+%  SetLogMethod() sets the method to be called when logging.
 %
 %  The format of the SetLogMethod method is:
 %
-%      SetLogFormat(LogMethod)
+%      void SetLogMethod(LogMethod method)
 %
 %  A description of each parameter follows:
 %
 %    o method: pointer to a method that will be called when LogMagickEvent is
 %      being called.
LogMagickEvent +%      is called.  Pass a null pointer to remove a registered method.
 %
 %
 */
@@ -1243,8 +1241,17 @@
 {
   LockSemaphoreInfo(log_info->log_semaphore);
 
-  log_info->output_type=(LogOutputType) (log_info->output_type |
-    MethodOutput);
+  if (method == (LogMethod) NULL)
+    {
+      log_info->output_type=(LogOutputType)
+        (log_info->output_type & ~MethodOutput);
+    }
+  else
+    {
+      log_info->output_type=(LogOutputType)
+        (log_info->output_type | MethodOutput);
+    }
+
   log_info->method=method;
 
   UnlockSemaphoreInfo(log_info->log_semaphore);
@@ -445,11 +445,11 @@
 %  The format of the LogMagickEvent method is:
 %
-%      unsigned int LogMagickEvent(const LogEventType type,const char *module,
+%      MagickPassFail LogMagickEvent(const LogEventType type,const char *module,
 %        const char *function,const unsigned long line,const char *format,...)
 %
@@ -1223,19 +1222,18 @@
 %  A description of each parameter follows:
 %
-%    o method: pointer to a method that will be called when LogMagickEvent is
-%      being called.
+%    o method: pointer to a method of type LogMethod that will be called when \
LogMagickEvent +%      is called.  Pass a null pointer to remove a registered method.
 %